const { S3Client, PutObjectCommand } = require('@aws-sdk/client-s3'); // Importer le client S3
const express = require('express');
const multer = require('multer');
const upload = multer();

const app = express();
const BUCKET_NAME = 'my-file-system'; // Remplace par le nom du bucket fourni
const REGION = 'us-east-1'; // Région de ton bucket S3 (remplace si nécessaire)

// Initialiser le client S3
const s3 = new S3Client({ region: REGION });

// Configuration d’EJS
app.set('view engine', 'ejs');
app.set('views', './views');

// Route pour afficher le formulaire d'upload
app.get('/', (req, res) => {
    res.render('index'); // Rend le fichier views/index.ejs
});

// Route pour uploader une image
app.post('/upload', upload.single('file'), async (req, res) => {
    if (!req.file) {
        return res.status(400).json({ error: 'Aucun fichier fourni' });
    }

    const params = {
        Bucket: BUCKET_NAME,
        Key: req.file.originalname, // Utiliser le nom d'origine du fichier
        Body: req.file.buffer, // Le contenu du fichier
        ContentType: req.file.mimetype, // Type MIME du fichier
    };

    try {
        // Utiliser la commande `PutObjectCommand` pour uploader l'image
        const data = await s3.send(new PutObjectCommand(params));
        res.render('success', { message: 'Image uploadée avec succès', data });
    } catch (err) {
        console.error(err);
        res.render('error', { error: 'Erreur lors de l\'upload' });
    }
});

// Ajouter cette condition pour exécuter Express localement
if (process.env.IS_OFFLINE) {
    const PORT = 3000; // Port local
    app.listen(PORT, () => {
        console.log(`Serveur local en écoute sur http://localhost:${PORT}`);
    });
}

module.exports.handler = require('serverless-http')(app);
